==> koffice-1.9.98.3.tar.bz2: koffice-1.9.98.3/libs/guiutils/KoProgressBar.cpp <==
/* This file is part of the KDE project
 * Copyright (C) Boudewijn Rempt <boud@valdyas.org>, (C) 2007
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "KoProgressBar.h"

#include <QApplication>

KoProgressBar::KoProgressBar( QWidget * parent )
 : QProgressBar( parent )
{
}

KoProgressBar::~KoProgressBar()
{
}

int KoProgressBar::maximum() const
{
    return QProgressBar::maximum();
}

void KoProgressBar::setValue( int value )
{
    QApplication::processEvents();
    if( value >= minimum() && value < maximum() )
    {
        QProgressBar::setValue( value );
        setVisible( true );
    } else {
        setVisible( false );
    }
}

void KoProgressBar::setRange( int minimum, int maximum )
{
    QProgressBar::setRange( minimum, maximum );
}

void KoProgressBar::setFormat( const QString & format )
{
    QProgressBar::setFormat( format );
}

==> koffice-1.9.98.7.tar.bz2: koffice-1.9.98.7/libs/guiutils/KoProgressBar.cpp <==
/* This file is part of the KDE project
 * Copyright (C) Boudewijn Rempt <boud@valdyas.org>, (C) 2007
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "KoProgressBar.h"

#include <QApplication>

KoProgressBar::KoProgressBar( QWidget * parent )
 : QProgressBar( parent )
{
}

KoProgressBar::~KoProgressBar()
{
}

int KoProgressBar::maximum() const
{
    return QProgressBar::maximum();
}

void KoProgressBar::setValue( int value )
{
    QApplication::processEvents(QEventLoop::ExcludeUserInputEvents);
    if( value >= minimum() && value < maximum() )
    {
        QProgressBar::setValue( value );
        setVisible( true );
    } else {
        setVisible( false );
    }
}

void KoProgressBar::setRange( int minimum, int maximum )
{
    QProgressBar::setRange( minimum, maximum );
}

void KoProgressBar::setFormat( const QString & format )
{
    QProgressBar::setFormat( format );
}
